@@ -1,9 +1,10 @@
 use chrono::Local;
-use pueue_lib::{
-    Settings, Task, TaskStatus, format::format_datetime, network::message::*, success_msg,
-};
+use pueue_lib::{Settings, Task, TaskStatus, message::*, success_msg};
 
-use crate::daemon::{internal_state::SharedState, network::response_helper::*};
+use crate::{
+    daemon::{internal_state::SharedState, network::response_helper::*},
+    format::format_datetime,
+};
 
 /// Invoked when calling `pueue enqueue`.
 /// Enqueue specific stashed tasks.
