@@ -1,7 +1,7 @@
 use std::collections::HashMap;
 
 use assert_matches::assert_matches;
-use pueue_lib::{network::message::*, task::*};
+use pueue_lib::{message::*, task::*};
 
 use crate::{helper::*, internal_prelude::*};
 
