@@ -1,6 +1,8 @@
 mod add;
 mod aliases;
+mod callback;
 mod clean;
+mod dependencies;
 mod edit;
 mod environment_variables;
 mod group;
@@ -16,6 +18,7 @@ mod restart;
 mod restore;
 /// Tests for shutting down the daemon.
 mod shutdown;
+mod socket_permissions;
 mod spawn;
 mod start;
 mod stashed;
