@@ -1,6 +1,6 @@
 use std::path::PathBuf;
 
-use pueue_lib::{Task, network::message::*};
+use pueue_lib::{Task, message::*};
 
 use crate::{helper::*, internal_prelude::*};
 
