@@ -1,6 +1,4 @@
-use anyhow::{Context, Result};
-
-use crate::helper::*;
+use crate::{helper::*, internal_prelude::*};
 
 /// Spin up the daemon and send a SIGTERM shortly afterwards.
 /// This should trigger the graceful shutdown and kill the process.
@@ -19,7 +17,10 @@ async fn test_ctrlc() -> Result<()> {
     sleep_ms(500).await;
 
     let result = child.try_wait();
-    assert!(matches!(result, Ok(Some(_))));
+    if !matches!(result, Ok(Some(_))) {
+        println!("Got error when sending SIGTERM to daemon. {result:?}");
+        bail!("Daemon process crashed after sending SIGTERM.");
+    }
     let code = result.unwrap().unwrap();
     assert!(matches!(code.code(), Some(0)));
 
