@@ -1,2 +1,4 @@
 mod integration;
 mod state_backward_compatibility;
+mod tls_socket;
+mod unix_socket;
