@@ -1,17 +1,20 @@
-use std::collections::HashMap;
-use std::env::temp_dir;
-use std::fs::{canonicalize, File};
-use std::io::Write;
-use std::path::{Path, PathBuf};
-use std::process::{Child, Command, Stdio};
+use std::{
+    collections::HashMap,
+    env::temp_dir,
+    fs::{File, canonicalize},
+    io::Write,
+    path::{Path, PathBuf},
+    process::{Child, Command, Stdio},
+};
 
-use anyhow::{bail, Context, Result};
 use assert_cmd::prelude::*;
-use tempfile::{Builder, TempDir};
-use tokio::io::{self, AsyncWriteExt};
-
 use pueue::daemon::run;
 use pueue_lib::settings::*;
+use tempfile::{Builder, TempDir};
+use tokio::{
+    io::{self, AsyncWriteExt},
+    task::JoinHandle,
+};
 
 use crate::helper::*;
 
@@ -20,7 +23,20 @@ use crate::helper::*;
 pub struct PueueDaemon {
     pub settings: Settings,
     pub tempdir: TempDir,
+    #[allow(dead_code)]
     pub pid: i32,
+    // The async join handle of the daemon function.
+    // Can be used to abort the daemon manually.
+    pub join_handle: JoinHandle<Result<()>>,
+}
+
+/// Implement a custom drop for the Daemon test struct
+impl Drop for PueueDaemon {
+    fn drop(&mut self) {
+        // The daemon runs in background tokio task.
+        // Use this handle to make sure that it gets always killed.
+        let _ = self.join_handle.abort_handle();
+    }
 }
 
 /// A helper function which creates some test config, sets up a temporary directory and spawns
@@ -28,7 +44,6 @@ pub struct PueueDaemon {
 /// This is done in 90% of our tests, thereby this convenience helper.
 pub async fn daemon() -> Result<PueueDaemon> {
     let (settings, tempdir) = daemon_base_setup()?;
-
     daemon_with_settings(settings, tempdir).await
 }
 
@@ -37,12 +52,14 @@ pub async fn daemon() -> Result<PueueDaemon> {
 pub async fn daemon_with_settings(settings: Settings, tempdir: TempDir) -> Result<PueueDaemon> {
     // Uncomment the next line to get some daemon logging.
     // Ignore any logger initialization errors, as multiple loggers will be initialized.
-    //let _ = simplelog::SimpleLogger::init(log::LevelFilter::Debug, simplelog::Config::default());
+    // let _ =
+    //     simplelog::SimpleLogger::init(simplelog::LevelFilter::Debug,
+    // simplelog::Config::default());
 
     let pueue_dir = tempdir.path();
     let path = pueue_dir.to_path_buf();
     // Start/spin off the daemon and get its PID
-    tokio::spawn(run_and_handle_error(path, true));
+    let join_handle = tokio::spawn(run_and_handle_error(path, true));
     let pid = get_pid(&settings.shared.pid_path()).await?;
 
     let sleep = 50;
@@ -59,6 +76,7 @@ pub async fn daemon_with_settings(settings: Settings, tempdir: TempDir) -> Resul
                 settings,
                 tempdir,
                 pid,
+                join_handle,
             });
         }
 
@@ -152,12 +170,21 @@ pub fn daemon_base_setup() -> Result<(Settings, TempDir)> {
     let client = Client {
         max_status_lines: Some(15),
         status_datetime_format: "%Y-%m-%d %H:%M:%S".into(),
+        edit_mode: EditMode::Files,
         ..Default::default()
     };
 
     #[allow(deprecated)]
     let daemon = Daemon {
         callback_log_lines: 15,
+        // Explicitly use bash to ensure that everyone uses the same shell
+        // when executing tests. For example, Debian uses `dash` as default shell,
+        // which expectes another syntax. We use `bash` as a common denominator.
+        shell_command: Some(vec![
+            "bash".into(),
+            "-c".into(),
+            "{{ pueue_command_string }}".into(),
+        ]),
         ..Default::default()
     };
 
