@@ -1,21 +1,18 @@
-/// This module contains helper functions to work with Pueue's asynchronous nature during tests.
-/// As the daemon often needs some time to process requests by the client internally, we cannot
-/// check whether the requested actions have been taken right away.
+use pueue_lib::{settings::Shared, state::GroupStatus, task::Task};
+
+use super::{get_state, sleep_ms};
+use crate::helper::TIMEOUT;
+/// This module contains helper functions to work with Pueue's asynchronous nature during
+/// tests. As the daemon often needs some time to process requests by the client internally, we
+/// cannot check whether the requested actions have been taken right away.
 ///
 /// Using continuous lookups, we can allow long waiting times, while still having fast tests if
 /// things don't take that long.
-use anyhow::{bail, Result};
-
-use pueue_lib::settings::Shared;
-use pueue_lib::state::GroupStatus;
-use pueue_lib::task::Task;
-
-use crate::helper::TIMEOUT;
-
-use super::{get_state, sleep_ms};
+use crate::internal_prelude::*;
 
 /// This is a small helper function, which checks in very short intervals, whether a task fulfills
-/// a certain criteria. This is necessary to prevent long or potentially flaky timeouts in our tests.
+/// a certain criteria. This is necessary to prevent long or potentially flaky timeouts in our
+/// tests.
 pub async fn wait_for_task_condition<F>(
     shared: &Shared,
     task_id: usize,
@@ -47,7 +44,7 @@ where
             }
         }
     }
-    bail!("Task {task_id} didn't fulfill condition after about 1 second.")
+    bail!("Task {task_id} didn't fulfill condition after ~1 second.")
 }
 
 /// This is a small helper function, which checks in very short intervals, whether a task has been
@@ -67,7 +64,7 @@ pub async fn wait_for_task_absence(shared: &Shared, task_id: usize) -> Result<()
         return Ok(());
     }
 
-    bail!("Task {task_id} hasn't been removed after about 1 second.")
+    bail!("Task {task_id} hasn't been removed after ~1 second.")
 }
 
 /// This is a small helper function, which checks in very short intervals, whether a group has been
@@ -87,7 +84,7 @@ pub async fn wait_for_group(shared: &Shared, group: &str) -> Result<()> {
         return Ok(());
     }
 
-    bail!("Group {group} didn't show up in about 1 second.")
+    bail!("Group {group} didn't show up in ~1 second.")
 }
 
 /// This is a small helper function, which checks in very short intervals, whether a group has been
@@ -107,7 +104,7 @@ pub async fn wait_for_group_absence(shared: &Shared, group: &str) -> Result<()>
         return Ok(());
     }
 
-    bail!("Group {group} hasn't been removed after about 1 second.")
+    bail!("Group {group} hasn't been removed after ~1 second.")
 }
 
 /// Waits for a status on a specific group.
@@ -140,5 +137,5 @@ pub async fn wait_for_group_status(
         }
     }
 
-    bail!("Group {group} didn't change to state {expected_status:?} after about 1 second",);
+    bail!("Group {group} didn't change to state {expected_status:?} after ~1 second",);
 }
