@@ -1,11 +1,10 @@
 use std::{fs, path::PathBuf};
 
-use anyhow::{Context, Result};
+use color_eyre::{Result, eyre::WrapErr};
+use pueue_lib::state::{GroupStatus, PUEUE_DEFAULT_GROUP, State};
 
-use pueue_lib::state::{GroupStatus, State, PUEUE_DEFAULT_GROUP};
-
-/// From 0.18.0 on, we aim to have full backward compatibility for our state deserialization.
-/// For this reason, an old (slightly modified) v0.18.0 serialized state has been checked in.
+/// We aim to have full backward compatibility for our state deserialization for as long as
+/// possible. For this reason, an old v4.0.0 serialized state has been checked in.
 ///
 /// **Warning**: This is only one part of our state tests.
 ///              There is another full test suite in the `pueue` project, which deals with domain
@@ -14,22 +13,19 @@ use pueue_lib::state::{GroupStatus, State, PUEUE_DEFAULT_GROUP};
 ///
 /// We have to be able to restore from that state at all costs.
 /// Everything else results in a breaking change and needs a major version change.
-/// (For `pueue_lib` as well as `pueue`!
-///
-/// On top of simply having an old state, I also removed a few default fields.
-/// This should be handled as well.
+/// (For `pueue_lib` as well as `pueue`!)
 #[test]
 fn test_restore_from_old_state() -> Result<()> {
     better_panic::install();
     let path = PathBuf::from(env!("CARGO_MANIFEST_DIR"))
         .join("tests")
         .join("data")
-        .join("v0.19.0_state.json");
+        .join("v4.0.0_state.json");
 
     // Try to load the file.
-    let data = fs::read_to_string(path).context("State restore: Failed to read file")?;
+    let data = fs::read_to_string(path).wrap_err("State restore: Failed to read file")?;
     // Try to deserialize the state file.
-    let state: State = serde_json::from_str(&data).context("Failed to deserialize state.")?;
+    let state: State = serde_json::from_str(&data).wrap_err("Failed to deserialize state.")?;
 
     // Make sure the groups are loaded.
     assert!(
@@ -46,11 +42,11 @@ fn test_restore_from_old_state() -> Result<()> {
     );
     assert_eq!(
         state.groups.get("test").unwrap().status,
-        GroupStatus::Paused
+        GroupStatus::Running
     );
 
     assert!(state.tasks.contains_key(&3), "Task 3 should exist");
-    assert_eq!(state.tasks.get(&3).unwrap().command, "ls stash_it");
+    assert_eq!(state.tasks.get(&3).unwrap().command, "sleep 9000000");
 
     Ok(())
 }
